@@ -58,7 +58,7 @@ local SECTION_AR  = 3
 
 
 local _M = {
-    _VERSION    = '0.19',
+    _VERSION    = '0.20',
     TYPE_A      = TYPE_A,
     TYPE_NS     = TYPE_NS,
     TYPE_CNAME  = TYPE_CNAME,
@@ -294,7 +294,7 @@ local function _build_request(qname, id, no_recurse, opts)
     local nan = "\0\0"
     local nns = "\0\0"
     local nar = "\0\0"
-    local typ = "\0" .. char(qtype)
+    local typ = char(rshift(qtype, 8), band(qtype, 0xff))
     local class = "\0\1"    -- the Internet class
 
     if byte(qname, 1) == DOT_CHAR then
